@@ -100,9 +100,8 @@ func newConf(ctx context.Context, conf config.Config) (l Config, err error) {
 		// add user to docker group
 		// "sudo", "usermod", "-aG", "docker", user
 		l.Provision = append(l.Provision, Provision{
-			Mode:           ProvisionModeDependency,
-			Script:         "groupadd -f docker && usermod -aG docker $LIMA_CIDATA_USER",
-			SkipResolution: true,
+			Mode:   ProvisionModeDependency,
+			Script: "groupadd -f docker && usermod -aG docker $LIMA_CIDATA_USER",
 		})
 
 		// set hostname
@@ -254,15 +253,6 @@ func newConf(ctx context.Context, conf config.Config) (l Config, err error) {
 		Script: `readlink /usr/sbin/fstrim || fstrim -a`,
 	})
 
-	// workaround for slow virtiofs https://github.com/drud/ddev/issues/4466#issuecomment-1361261185
-	// TODO: remove when fixed upstream
-	if l.MountType == VIRTIOFS {
-		l.Provision = append(l.Provision, Provision{
-			Mode:   ProvisionModeSystem,
-			Script: `stat /sys/class/block/vda/queue/write_cache && echo 'write through' > /sys/class/block/vda/queue/write_cache`,
-		})
-	}
-
 	if len(conf.Mounts) == 0 {
 		l.Mounts = append(l.Mounts,
 			Mount{Location: "~", Writable: true},
